   #include p12F629.inc

; ADFxxxx SPI Programmer.

; CONFIG
; Set Osc to be internal 4 MHz with GP4 and GP5 as IOs xxxxxx xxxxx100
; Set Watchdog timer off                               xxxxxx xxxx0xxx
; Set Power-up timer enabled                           xxxxxx xxx0xxxx
; Set GP3 as GPIO (0), not MCLR(1)                     xxxxxx xx0xxxxx
; Disable Brown-out detect                             xxxxxx x0xxxxxx
; Disable program code protection                      xxxxxx 1xxxxxxx
; Disable data code protection                         xxxxx1 xxxxxxxx
; Bandgap - highest                                    11000x xxxxxxxx

    __config 0x3184

;-------Project Registers------------------
SWNOW	EQU	0x20   	; Switches as read now.  Bits 0, 1 and 2
SWPREV	EQU	0x21	; Switches as previously read
WDCNT	EQU	0x22	; Counts words sent from 12 to 0
CHAN	EQU	0x23	; Channel: 0 , 64, 128 or 192
BYTCNT	EQU	0x24	; Byte count 0 to (3*64 + 51)
BITCNT	EQU	0x25	; Bit count from 8 to 1 (skips out at 0)
CNT8S	EQU	0x26	; Counts the 8s within each 32 bit word down from 4 to 1
SHIFTR	EQU	0x27	; Shift register for sending bits
;	EQU	0x28	; 
;	EQU	0x29	; 
;	EQU	0x2A	; 
;	EQU	0x2B	; 
;	EQU	0x2C	; 
;	EQU	0x2D	; 
;	EQU	0x2E	; 
;	EQU	0x2F	; 
;	EQU	0x30	; 
;	EQU	0x31	; 
;	EQU	0x32	; 
;	EQU	0x33	; 
;	EQU	0x34	; 
;	EQU	0x35	; 
;	EQU	0x36	; 
;	EQU	0x37	; 
;	EQU	0x38	; 
;	EQU	0x39	; 
;	EQU	0x3A	; 
;	EQU	0x3B	; 
;	EQU	0x3C	; 
;	EQU	0x3D	; 
;	EQU	0x3E	; 
;	EQU	0x3F	; 
;	EQU	0x40	; 
;	EQU	0x41	; 
;	EQU	0x42	; 
;	EQU	0x43	; 
;	EQU	0x44	; 
;	EQU	0x45	; 
;	EQU	0x46	; 
;	EQU	0x47	; 
;	EQU	0x48	; 
;	EQU	0x49	; 
;	EQU	0x4A	; 
;	EQU	0x4B	; 
;	EQU	0x4C	; 
;	EQU	0x4D	; 
;	EQU	0x4E	; 
;	EQU	0x4F	; 
;	EQU	0x50	; 
;	EQU	0x51	; 
;	EQU	0x52	; 
T1	EQU	0x53	; Delay counter in DEL1M
T2	EQU	0x54	; Delay counter in DELPT5 and DELPT1
;	EQU	0x55	; 
;	EQU	0x56	; 
;	EQU	0x57	; 
;	EQU	0x58	; 
;	EQU	0x59	; 
;	EQU	0x5A	; 
;	EQU	0x5B	; 
;	EQU	0x5C	; 
;	EQU	0x5D	; 
;	EQU	0x5E	; 
;	EQU	0x5F	; 

CARRY            EQU  H'0000'
DC               EQU  H'0001'
ZERO             EQU  H'0002'
NOT_PD           EQU  H'0003'
NOT_TO           EQU  H'0004'
IRP              EQU  H'0007'

RP0              EQU  H'0005'
RP1              EQU  H'0006'
	
; Config:
;*******************************************************************************
; MAIN PROGRAM
;*******************************************************************************
;
; GP0 Pin 7 ADF     Clock and programming PGC=5     output          0
; GP1 Pin 6 ADF     Data and programming PGD=4      output          0
; GP2 Pin 5 ADF     LE                              output          0
; GP3 Pin 4 MCLR or switch S3 to ground             input           0
; GP4 Pin 3 Switch S2 to ground                     input           0
; GP5 Pin 2 Switch S1 to ground                     input           0
; Note that GP3 needs a 10K to Vdd  and is used to prompt a re-send only
; by grounding it.  Channels are selected on S1 and S2 

; Addresses 0x000 - 0x0FF are main program      
; Addresses 0x100 - 0x1FF are subroutines      
; Addresses 0x200 - 0x300 are look-up tables for PIC Words      
	      
	ORG	0x00

START

; -------- Initialise ports -----------------------

STT	BCF	STATUS, RP0		; Bank 0

	BSF	STATUS, RP0 		; Bank 1
	
	MOVLW   0x7F			; MSB cleared to enable weak pull-ups
   	MOVWF   OPTION_REG		; Enable weak pull-ups
        
	MOVLW   0x38			; 1 input, 0 output xx111000
   	MOVWF   TRISIO			; Set port directions

	MOVLW   0x30			; 1 WPU enabled, 0 disabled xx11x000
   	MOVWF   WPU				; Enable Weak pull-up on GP4 and GP5

	BCF	STATUS, RP0			; Bank 0
	
	MOVLW	0x04			; Initialise port values xxxxx100
							; Clk GP0 lo, Data GP1 lo, LE GP2 hi
	MOVWF	GPIO			; Write to ports
	
; -------- End Initialise Ports ------------------

; Program Sequence
;
; Wait 0.5 seconds
; Read switches, store switch value
; Send 6 or 11 words
; Wait 0.1 seconds
; Read switches
; Has value changed?  If not go back to wait
; Value changed, wait 0.1 seconds
; Has value still changed? If not, go back to wait
; If value has changed, store new switch value, go back to send 6 or 11 words

; 	Wait for ADF board to stabilise

	CALL	DELPT5			; Half second delay

;	Read switches

	MOVF	GPIO, W			; Switches are on bits 3, 4 and 5
	ANDLW	0x38			; Mask the switches
	BCF	STATUS, CARRY		; Clear the carry bit
	MOVWF	SWNOW			; Move the switch state into SWNOW
	RRF	SWNOW, F			; Move switches right
	RRF	SWNOW, F			; Move switches right
	RRF	SWNOW, F			; Move switches right.  Now bits 0, 1 and 2

;	Start setting a frequency here

NEWFREQ	NOP
	MOVF	SWNOW, W		; Move the current switch position into W
	MOVWF	SWPREV			; and set it as the previous condition

;	Allow 64 bytes for each frequency. Limit to 4 frequencies in this version
;	ADF4351 needs 6 words of 4 bytes
;	ADF4513 needs 6 words of 4 bytes
;	ADF5355 needs 13 words of 4 bytes

	MOVF	SWNOW, W		; Move the switch state into W
	MOVWF	CHAN			; and into the channel:  0 0 0 0    0 S1 S2 S3
	BCF	STATUS, CARRY		; Clear the carry bit
	BCF	CHAN, 0				; Clear S3.  Now base 2: 0 0 0 0    0 S1 S2 0
	RLF	CHAN, F				; Now base 4:            0 0 0 0    
	RLF	CHAN, F				; Now base 8:            0 0 0 S1   S2 0 0 0
	RLF	CHAN, F				; Now base 16:           0 0 S1 S2  0 0 0 0
	RLF	CHAN, F				; Now base 32:           0 S1 S2 0  0 0 0 0
	RLF	CHAN, F				; Now base 64:           S1 S2 0 0  0 0 0 0

;	CLRF	CHAN			; Uncomment for single frequency version

	MOVF	CHAN, W			; Move channel (0, 64, 128 or 192) into W
	MOVWF	BYTCNT			; and into the Byte look-up address
	
;	Loop for number of words required

;	MOVLW	0x0D			; 13.  Uncomment for ADF5355
	MOVLW	0x06			; 6.  Uncomment for ADF4351 or ADF4513
	MOVWF	WDCNT			;

WDLOOP	NOP					; top of word loop
	DECF	WDCNT, F		; Start word count at 12 or 5, finish at 0

	BCF	GPIO, 2				; Set LE low for first word
	MOVLW	0x04			; Move 4 (for 32-bit words)
	MOVWF	CNT8S			; Into the 8s counter

BYTELOOP	NOP
	MOVLW	0x08			; Move 8
	MOVWF	BITCNT			; Into the bit counter
	
	MOVLW	0x02			; Load High byte of PC
	MOVWF	PCLATH			; set high byte of PC for lookup

	MOVF	BYTCNT, W		; Move the byte look-up address to be fetched into W
	CALL	LUBYTE			; Fetch the byte value
	MOVWF	SHIFTR			; Put the byte value in the shift register

BITLOOP	NOP
	BTFSC	SHIFTR, 7		; test the MSB
	BSF	GPIO, 1				; default data is low, so if bit not clear, set high
	NOP
	NOP
	NOP
	BSF	GPIO, 0				; Set clock high
	NOP
	NOP
	NOP
	BCF	GPIO, 0				; Set clock low
	NOP
	NOP
	NOP
	BCF	GPIO, 1				; Set data low

	BCF	STATUS, CARRY		; Clear the carry bit
	RLF	SHIFTR, F			; Shift the next bit in
	
	DECFSZ	BITCNT, F		; Decrement the bit counter
	GOTO	BITLOOP			; Do another bit if non-zero, else look for the next byte

	INCF	BYTCNT, F		; Increment the byte look-up address

	DECFSZ	CNT8S, F		; Decrement the byte counter
	GOTO	BYTELOOP		; Do another if non-zero
	
	BSF	GPIO, 2				; End of 32 bits, so Set LE high
	
	NOP
	NOP
	NOP
	
	MOVF	WDCNT, F		; Set the 0 bit if WDCNT is zero
	BTFSS	STATUS, ZERO	; Skip next if set (zero)
	GOTO	WDLOOP			; non zero, so send the next word
	
;	End of sending the commands to the PIC

WAIT1	CALL	DELPT1		; Wait 0.1 second

;	Check the switches

	MOVF	GPIO, W			; Switches are on bits 3, 4 and 5
	ANDLW	0x38			; Mask the switches
	BCF	STATUS, CARRY		; Clear the carry bit
	MOVWF	SWNOW			; Move the switch state into SWNOW
	RRF		SWNOW, F		; Move switches right
	RRF		SWNOW, F		; Move switches right
	RRF		SWNOW, F		; Move switches right.  Now bits 0, 1 and 2
	MOVF	SWNOW, W		; Move current state into W

	SUBWF	SWPREV, W		; Set the zero bit if switches the same as previous

	BTFSC	STATUS, ZERO	; Skip next if clear (non-zero)
	GOTO	WAIT1			; Try again
	
	CALL	DELPT1			; Wait 0.1 second
	MOVF	GPIO, W			; Switches are on bits 3, 4 and 5
	ANDLW	0x38			; Mask the switches
	BCF		STATUS, CARRY	; Clear the carry bit
	MOVWF	SWNOW			; Move the switch state into SWNOW
	RRF		SWNOW, F		; Move switches right
	RRF		SWNOW, F		; Move switches right
	RRF		SWNOW, F		; Move switches right.  Now bits 0, 1 and 2
	MOVF	SWNOW, W		; Move current state into W

	SUBWF	SWPREV, W		; Set the zero bit if switches the same as previous

	BTFSC	STATUS, ZERO	; Skip next if non-zero
	GOTO	WAIT1			; Wait for switch change

;	New frequency required

	GOTO	NEWFREQ			; Send a new set of codes

; ===== End main code here ======================================================

    ORG 0x100
; ----- DEL1M - DELAY 1 MILLISECOND -------------------------------------

;	Each instruction is 1 microsecond (4 MHz/4)
;	So delay 1000 instruction steps including call and return

DEL1M	MOVLW	0xF8	; 3 LOAD 248 (times 4 = 992 cycles)
	MOVWF	T1	; 4 INTO W and then T1
DEL1ML	NOP		; 5     9         993 NOP for extra cycle (4)
	DECFSZ	T1, F	; 6     10        994 Decrement T1, is it zero?
	GOTO	DEL1ML	; 7, 8  11, 12        No, so do it again
	NOP		; Yes so return   996
	NOP		;                 997
	NOP		;                 998
	RETURN		;                 999, 1000

; ----- End of DEL1M ----------------------------------------------------


; ----- DELPT1 - DELAY 100 MILLISECOND -------------------------------------

DELPT1	MOVLW	0x64	; LOAD 100 to wait 100 ms
	MOVWF	T2	; INTO W and then T2
DELPT1L	CALL	DEL1M	; Delay 1 millisecond
	DECFSZ	T2, F	; Decrement T2, is it zero?
	GOTO	DELPT1L	; No, so do it again
	RETURN		; Yes so return

; ----- End of DEL1M ----------------------------------------------------


; ----- DELPT5 - DELAY 500 MILLISECOND -------------------------------------

DELPT5	MOVLW	0xFA	; LOAD 250 to wait 250 ms
	MOVWF	T2	; INTO W and then T2
DELPT5L	CALL	DEL1M	; Delay 1 millisecond
	DECFSZ	T2, F	; Decrement T2, is it zero?
	GOTO	DELPT5L	; No, so do it again
			; Yes, so wait the second 250 ms
	MOVLW	0xFA	; LOAD 250
	MOVWF	T2	; INTO W and then T2
DELPS5L	CALL	DEL1M	; Delay 1 millisecond
	DECFSZ	T2, F	; Decrement T2, is it zero?
	GOTO	DELPS5L	; No, so do it again
	RETURN		; Yes so return

; ----- End of DELPT5 ----------------------------------------------------


	ORG	0x200

; ----- LUBYTE - Lookup for bytes to program with --------------------------------

LUBYTE	ADDWF	PCL, F		; calculate Program Counter jump based on W#

; Channel 0 is used for single channel versions.  (Uncomment line 185)
; Note that channel 3 will be the default for 4-channel versions with
;  no DIP switch installed to ground SW1 and SW2
; Chan 0 Italian LO ADF4153 12024.1/4 GHz, 20 MHz ref
; 0x00000003, 0x000003C7, 0x00001BC6, 0x00145901, 0x0012C3C4, 0x00001BC2

;	0x00000003		;  Chan 0, ADF5355 Word 12, ADF4351 Reg 5, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x000003C7		;  Chan 0, ADF5355 Word 11, ADF4351 Reg 4, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x03
	RETLW	0xC7

;	0x00001BC6		;  Chan 0, ADF5355 Word 10, ADF4351 Reg 3, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC6

;	0x00145901		;  Chan 0, ADF5355 Word 9, ADF4351 Reg 2, , ADF4513 Reg 1

	RETLW	0x00
	RETLW	0x14
	RETLW	0x59
	RETLW	0x01

;	0x0012C3C4		;  Chan 0, ADF5355 Word 8, ADF4351 Reg 1, ADF4513 Reg 0 

	RETLW	0x00
	RETLW	0x12
	RETLW	0xC3
	RETLW	0xC4

;	0x00001BC2		;  Chan 0, ADF5355 Word 7, ADF4351 Reg 0, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC2

;	0x35038036		;  Chan 0, ADF5355 Word 6

	RETLW	0x35
	RETLW	0x03
	RETLW	0x80
	RETLW	0x36

;	0x00800025		;  Chan 0, ADF5355 Word 5

	RETLW	0x00
	RETLW	0x80
	RETLW	0x00
	RETLW	0x25

;	0x3400A784		;  Chan 0, ADF5355 Word 4

	RETLW	0x34
	RETLW	0x00
	RETLW	0xA7
	RETLW	0x84

;	0x00000003		;  Chan 0, ADF5355 Word 3

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x6277FFF2		;  Chan 0, ADF5355 Word 2

	RETLW	0x62
	RETLW	0x77
	RETLW	0xFF
	RETLW	0xF2

;	0x08276271		;  Chan 0, ADF5355 Word 1

	RETLW	0x08
	RETLW	0x27
	RETLW	0x62
	RETLW	0x71

;	0x00200710		;  Chan 0, ADF5355 Word 0

	RETLW	0x00
	RETLW	0x20
	RETLW	0x07
	RETLW	0x10

;	0x00000000		;  Chan 0, Word (13) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 0, Word (14) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 0, Word (15) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	
; Start Channel 1 here ======================================================

; Channel 1, Italian LO 20 MHz Ref 12024/4 MHz Lowest phase noise
; R3 00000003, R3 000003C7, R2 00001BC6 R1 00144281, R0 0012C060, R2 00001BC2

;	0x00000003		;  Chan 1, ADF5355 Word 12, ADF4351 Reg 5, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x000003C7		;  Chan 1, ADF5355 Word 11, ADF4351 Reg 4, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x03
	RETLW	0xC7

;	0x00001BC6		;  Chan 1, ADF5355 Word 10, ADF4351 Reg 3, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC6

;	0x00144281		;  Chan 1, ADF5355 Word 9, ADF4351 Reg 2, , ADF4513 Reg 1

	RETLW	0x00
	RETLW	0x14
	RETLW	0x42
	RETLW	0x81

;	0x0012C060		;  Chan 1, ADF5355 Word 8, ADF4351 Reg 1, ADF4513 Reg 0 

	RETLW	0x00
	RETLW	0x12
	RETLW	0xC0
	RETLW	0x60

;	0x00001BC2		;  Chan 1, ADF5355 Word 7, ADF4351 Reg 0, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC2

;	0x35038036		;  Chan 1, ADF5355 Word 6

	RETLW	0x35
	RETLW	0x03
	RETLW	0x80
	RETLW	0x36

;	0x00800025		;  Chan 1, ADF5355 Word 5

	RETLW	0x00
	RETLW	0x80
	RETLW	0x00
	RETLW	0x25

;	0x3400A784		;  Chan 1, ADF5355 Word 4

	RETLW	0x34
	RETLW	0x00
	RETLW	0xA7
	RETLW	0x84

;	0x00000003		;  Chan 1, ADF5355 Word 3

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x6277FFF2		;  Chan 1, ADF5355 Word 2

	RETLW	0x62
	RETLW	0x77
	RETLW	0xFF
	RETLW	0xF2

;	0x08276271		;  Chan 1, ADF5355 Word 1

	RETLW	0x08
	RETLW	0x27
	RETLW	0x62
	RETLW	0x71

;	0x00200710		;  Chan 1, ADF5355 Word 0

	RETLW	0x00
	RETLW	0x20
	RETLW	0x07
	RETLW	0x10

;	0x00000000		;  Chan 1, Word (13) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 1, Word (14) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 1, Word (15) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	
; Start Channel 2 here ======================================================	

; Channel 2, Italian LO 20 MHz Ref 12024/4 MHz Lowest phase noise
; R3 00000003, R3 000003C7, R2 00001BC6 R1 00144281, R0 0012C060, R2 00001BC2

;	0x00000003		;  Chan 2, ADF5355 Word 12, ADF4351 Reg 5, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x000003C7		;  Chan 2, ADF5355 Word 11, ADF4351 Reg 4, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x03
	RETLW	0xC7

;	0x00001BC6		;  Chan 2, ADF5355 Word 10, ADF4351 Reg 3, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC6

;	0x00144281		;  Chan 2, ADF5355 Word 9, ADF4351 Reg 2, , ADF4513 Reg 1

	RETLW	0x00
	RETLW	0x14
	RETLW	0x42
	RETLW	0x81

;	0x0012C060		;  Chan 2, ADF5355 Word 8, ADF4351 Reg 1, ADF4513 Reg 0 

	RETLW	0x00
	RETLW	0x12
	RETLW	0xC0
	RETLW	0x60

;	0x00001BC2		;  Chan 2, ADF5355 Word 7, ADF4351 Reg 0, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC2

;	0x35038036		;  Chan 2, ADF5355 Word 6

	RETLW	0x35
	RETLW	0x03
	RETLW	0x80
	RETLW	0x36

;	0x00800025		;  Chan 2, ADF5355 Word 5

	RETLW	0x00
	RETLW	0x80
	RETLW	0x00
	RETLW	0x25

;	0x3400A784		;  Chan 2, ADF5355 Word 4

	RETLW	0x34
	RETLW	0x00
	RETLW	0xA7
	RETLW	0x84

;	0x00000003		;  Chan 2, ADF5355 Word 3

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x6277FFF2		;  Chan 2, ADF5355 Word 2

	RETLW	0x62
	RETLW	0x77
	RETLW	0xFF
	RETLW	0xF2

;	0x08276271		;  Chan 2, ADF5355 Word 1

	RETLW	0x08
	RETLW	0x27
	RETLW	0x62
	RETLW	0x71

;	0x00200710		;  Chan 2, ADF5355 Word 0

	RETLW	0x00
	RETLW	0x20
	RETLW	0x07
	RETLW	0x10

;	0x00000000		;  Chan 2, Word (13) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 2, Word (14) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 2, Word (15) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

; Start Channel 3 here ======================================================

; Channel 3 is the default for 4-channel versions with 
;  no DIP switches installed.

; Channel 3, Italian LO 20 MHz Ref 11805/4 MHz Lowest phase noise
; R3 00000003, R3 000003C7, R2 00001BC6 R1 00144281, R0 001241F4, R2 00001BC2

;	0x00000003		;  Chan 3, ADF5355 Word 12, ADF4351 Reg 5, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x000003C7		;  Chan 3, ADF5355 Word 11, ADF4351 Reg 4, ADF4513 Reg 3 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x03
	RETLW	0xC7

;	0x00001BC6		;  Chan 3, ADF5355 Word 10, ADF4351 Reg 3, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC6

;	0x00144281		;  Chan 3, ADF5355 Word 9, ADF4351 Reg 2, ADF4513 Reg 1

	RETLW	0x00
	RETLW	0x14
	RETLW	0x42
	RETLW	0x81

;	0x001241F4		;  Chan 3, ADF5355 Word 8, ADF4351 Reg 1, ADF4513 Reg 0 

	RETLW	0x00
	RETLW	0x12
	RETLW	0x41
	RETLW	0xF4

;	0x00001BC2		;  Chan 3, ADF5355 Word 7, ADF4351 Reg 0, ADF4513 Reg 2 

	RETLW	0x00
	RETLW	0x00
	RETLW	0x1B
	RETLW	0xC2

;	0x35038036		;  Chan 3, ADF5355 Word 6

	RETLW	0x35
	RETLW	0x03
	RETLW	0x80
	RETLW	0x36

;	0x00800025		;  Chan 3, ADF5355 Word 5

	RETLW	0x00
	RETLW	0x80
	RETLW	0x00
	RETLW	0x25

;	0x3400A784		;  Chan 3, ADF5355 Word 4

	RETLW	0x34
	RETLW	0x00
	RETLW	0xA7
	RETLW	0x84

;	0x00000003		;  Chan 3, ADF5355 Word 3

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x03

;	0x6277FFF2		;  Chan 3, ADF5355 Word 2

	RETLW	0x62
	RETLW	0x77
	RETLW	0xFF
	RETLW	0xF2

;	0x08276271		;  Chan 3, ADF5355 Word 1

	RETLW	0x08
	RETLW	0x27
	RETLW	0x62
	RETLW	0x71

;	0x00200710		;  Chan 3, ADF5355 Word 0

	RETLW	0x00
	RETLW	0x20
	RETLW	0x07
	RETLW	0x10

;	0x00000000		;  Chan 3, Word (13) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 3, Word (14) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

;	0x00000000		;  Chan 3, Word (15) Not used

	RETLW	0x00
	RETLW	0x00
	RETLW	0x00
	RETLW	0x00

; End of Channel 3 ====================================

FINI	NOP
    END